@@ -47,6 +47,7 @@ class NaturalPersonEditPersonalDataView(EditView):
         "last_name",
         "gender",
         "date_of_birth",
+        "place_of_birth",
         "profession",
         "deceased",
         "decease_date",
@@ -88,6 +89,7 @@ class NaturalPersonEditPersonalDataView(EditView):
                 R(C(F("last_name"))),
                 R(C(F("gender"))),
                 R(C(F("date_of_birth"))),
+                R(C(F("place_of_birth"))),
                 R(C(F("profession"))),
                 R(C(F("deceased"))),
                 R(C(F("decease_date"))),
